@@ -6,49 +6,31 @@ The different objects are modules, classes, functions, and attribute
 
 from __future__ import annotations
 
-import enum
 import inspect
 from collections import defaultdict
 from contextlib import suppress
 from pathlib import Path
 from textwrap import dedent
-from typing import TYPE_CHECKING, Any, Callable, Sequence, Union, cast
+from typing import TYPE_CHECKING, Any, Callable, Literal, Sequence, Union, cast
 
 from griffe.c3linear import c3linear_merge
 from griffe.docstrings.parsers import Parser, parse
+from griffe.enumerations import Kind, ParameterKind
 from griffe.exceptions import AliasResolutionError, BuiltinModuleError, CyclicAliasError, NameResolutionError
-from griffe.expressions import Name
+from griffe.expressions import ExprCall, ExprName
 from griffe.logger import get_logger
 from griffe.mixins import GetMembersMixin, ObjectAliasMixin, SerializationMixin, SetMembersMixin
 
 if TYPE_CHECKING:
     from griffe.collections import LinesCollection, ModulesCollection
     from griffe.docstrings.dataclasses import DocstringSection
-    from griffe.expressions import Expression
+    from griffe.expressions import Expr
 
 from functools import cached_property
 
 logger = get_logger(__name__)
 
 
-class ParameterKind(enum.Enum):
-    """Enumeration of the different parameter kinds.
-
-    Attributes:
-        positional_only: Positional-only parameter.
-        positional_or_keyword: Positional or keyword parameter.
-        var_positional: Variadic positional parameter.
-        keyword_only: Keyword-only parameter.
-        var_keyword: Variadic keyword parameter.
-    """
-
-    positional_only: str = "positional-only"
-    positional_or_keyword: str = "positional or keyword"
-    var_positional: str = "variadic positional"
-    keyword_only: str = "keyword-only"
-    var_keyword: str = "variadic keyword"
-
-
 class Decorator:
     """This class represents decorators.
 
@@ -57,7 +39,7 @@ class Decorator:
         endlineno: The ending line number.
     """
 
-    def __init__(self, value: str | Name | Expression, *, lineno: int | None, endlineno: int | None) -> None:
+    def __init__(self, value: str | Expr, *, lineno: int | None, endlineno: int | None) -> None:
         """Initialize the decorator.
 
         Parameters:
@@ -65,15 +47,15 @@ class Decorator:
             lineno: The starting line number.
             endlineno: The ending line number.
         """
-        self.value: str | Name | Expression = value
+        self.value: str | Expr = value
         self.lineno: int | None = lineno
         self.endlineno: int | None = endlineno
 
     @property
     def callable_path(self) -> str:
         """The path of the callable used as decorator."""
-        value = self.value if isinstance(self.value, str) else self.value.full
-        return value.split("(", 1)[0]
+        value = self.value.function if isinstance(self.value, ExprCall) else self.value
+        return value if isinstance(value, str) else value.canonical_path
 
     def as_dict(self, **kwargs: Any) -> dict[str, Any]:  # noqa: ARG002
         """Return this decorator's data as a dictionary.
@@ -108,7 +90,7 @@ class Docstring:
         lineno: int | None = None,
         endlineno: int | None = None,
         parent: Object | None = None,
-        parser: Parser | None = None,
+        parser: Literal["google", "numpy", "sphinx"] | Parser | None = None,
         parser_options: dict[str, Any] | None = None,
     ) -> None:
         """Initialize the docstring.
@@ -125,7 +107,7 @@ class Docstring:
         self.lineno: int | None = lineno
         self.endlineno: int | None = endlineno
         self.parent: Object | None = parent
-        self.parser: Parser | None = parser
+        self.parser: Literal["google", "numpy", "sphinx"] | Parser | None = parser
         self.parser_options: dict[str, Any] = parser_options or {}
 
     def __bool__(self) -> bool:
@@ -149,7 +131,11 @@ class Docstring:
         """
         return self.parse()
 
-    def parse(self, parser: Parser | None = None, **options: Any) -> list[DocstringSection]:
+    def parse(
+        self,
+        parser: Literal["google", "numpy", "sphinx"] | Parser | None = None,
+        **options: Any,
+    ) -> list[DocstringSection]:
         """Parse the docstring into structured data.
 
         Parameters:
@@ -197,9 +183,9 @@ class Parameter:
         self,
         name: str,
         *,
-        annotation: str | Name | Expression | None = None,
+        annotation: str | Expr | None = None,
         kind: ParameterKind | None = None,
-        default: str | Name | Expression | None = None,
+        default: str | Expr | None = None,
     ) -> None:
         """Initialize the parameter.
 
@@ -210,9 +196,9 @@ class Parameter:
             default: The parameter default, if any.
         """
         self.name: str = name
-        self.annotation: str | Name | Expression | None = annotation
+        self.annotation: str | Expr | None = annotation
         self.kind: ParameterKind | None = kind
-        self.default: str | Name | Expression | None = default
+        self.default: str | Expr | None = default
 
     def __str__(self) -> str:
         param = f"{self.name}: {self.annotation} = {self.default}"
@@ -293,23 +279,6 @@ class Parameters:
             raise ValueError(f"parameter {parameter.name} already present")
 
 
-class Kind(enum.Enum):
-    """Enumeration of the different objects kinds.
-
-    Attributes:
-        MODULE: The module kind.
-        CLASS: The class kind.
-        FUNCTION: The function kind.
-        ATTRIBUTE: The attribute kind.
-    """
-
-    MODULE: str = "module"
-    CLASS: str = "class"
-    FUNCTION: str = "function"
-    ATTRIBUTE: str = "attribute"
-    ALIAS: str = "alias"
-
-
 class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin, SerializationMixin):
     """An abstract class representing a Python object.
 
@@ -361,10 +330,11 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin, SerializationMi
         self.members: dict[str, Object | Alias] = {}
         self.labels: set[str] = set()
         self.imports: dict[str, str] = {}
-        self.exports: set[str] | list[str | Name] | None = None
+        self.exports: set[str] | list[str | ExprName] | None = None
         self.aliases: dict[str, Alias] = {}
         self.runtime: bool = runtime
         self.extra: dict[str, dict[str, Any]] = defaultdict(dict)
+        self.public: bool | None = None
         self._lines_collection: LinesCollection | None = lines_collection
         self._modules_collection: ModulesCollection | None = modules_collection
 
@@ -373,7 +343,7 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin, SerializationMi
             docstring.parent = self
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__name__}({self.name!r}, {self.lineno!r}, {self.endlineno!r})>"
+        return f"{self.__class__.__name__}({self.name!r}, {self.lineno!r}, {self.endlineno!r})"
 
     def __bool__(self) -> bool:
         return True
@@ -451,15 +421,6 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin, SerializationMi
                     inherited_members[name] = Alias(name, member, parent=self, inherited=True)
         return inherited_members
 
-    @property
-    def all_members(self) -> dict[str, Object | Alias]:
-        """All members (declared and inherited).
-
-        This method is part of the consumer API:
-        do not use when producing Griffe trees!
-        """
-        return {**self.inherited_members, **self.members}
-
     @property
     def is_module(self) -> bool:
         """Tell if this object is a module."""
@@ -508,54 +469,6 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin, SerializationMi
                 members[name] = member
         return members
 
-    @property
-    def modules(self) -> dict[str, Module]:
-        """Return the module members.
-
-        This method is part of the consumer API:
-        do not use when producing Griffe trees!
-
-        Returns:
-            A dictionary of modules.
-        """
-        return {name: member for name, member in self.all_members.items() if member.kind is Kind.MODULE}  # type: ignore[misc]
-
-    @property
-    def classes(self) -> dict[str, Class]:
-        """Return the class members.
-
-        This method is part of the consumer API:
-        do not use when producing Griffe trees!
-
-        Returns:
-            A dictionary of classes.
-        """
-        return {name: member for name, member in self.all_members.items() if member.kind is Kind.CLASS}  # type: ignore[misc]
-
-    @property
-    def functions(self) -> dict[str, Function]:
-        """Return the function members.
-
-        This method is part of the consumer API:
-        do not use when producing Griffe trees!
-
-        Returns:
-            A dictionary of functions.
-        """
-        return {name: member for name, member in self.all_members.items() if member.kind is Kind.FUNCTION}  # type: ignore[misc]
-
-    @property
-    def attributes(self) -> dict[str, Attribute]:
-        """Return the attribute members.
-
-        This method is part of the consumer API:
-        do not use when producing Griffe trees!
-
-        Returns:
-            A dictionary of attributes.
-        """
-        return {name: member for name, member in self.all_members.items() if member.kind is Kind.ATTRIBUTE}  # type: ignore[misc]
-
     @property
     def module(self) -> Module:
         """Return the parent module of this object.
@@ -829,7 +742,7 @@ class Alias(ObjectAliasMixin):
         lineno: int | None = None,
         endlineno: int | None = None,
         runtime: bool = True,
-        parent: Module | Class | None = None,
+        parent: Module | Class | Alias | None = None,
         inherited: bool = False,
     ) -> None:
         """Initialize the alias.
@@ -849,7 +762,8 @@ class Alias(ObjectAliasMixin):
         self.alias_endlineno: int | None = endlineno
         self.runtime: bool = runtime
         self.inherited: bool = inherited
-        self._parent: Module | Class | None = parent
+        self.public: bool | None = None
+        self._parent: Module | Class | Alias | None = parent
         self._passed_through: bool = False
         if isinstance(target, str):
             self._target: Object | Alias | None = None
@@ -860,7 +774,7 @@ class Alias(ObjectAliasMixin):
             self._update_target_aliases()
 
     def __repr__(self) -> str:
-        return f"<Alias({self.name!r}, {self.target_path!r})>"
+        return f"Alias({self.name!r}, {self.target_path!r})"
 
     def __getitem__(self, key: str | tuple[str, ...]):
         # not handled by __getattr__
@@ -927,7 +841,7 @@ class Alias(ObjectAliasMixin):
             return False
 
     @property
-    def parent(self) -> Module | Class | None:
+    def parent(self) -> Module | Class | Alias | None:
         """Return the parent of this alias.
 
         Returns:
@@ -936,7 +850,7 @@ class Alias(ObjectAliasMixin):
         return self._parent
 
     @parent.setter
-    def parent(self, value: Module | Class) -> None:
+    def parent(self, value: Module | Class | Alias) -> None:
         self._parent = value
         self._update_target_aliases()
 
@@ -969,9 +883,13 @@ class Alias(ObjectAliasMixin):
     def docstring(self, docstring: Docstring | None) -> None:
         self.final_target.docstring = docstring
 
-    @property
+    @cached_property
     def members(self) -> dict[str, Object | Alias]:  # noqa: D102
-        return self.final_target.members
+        final_target = self.final_target
+        return {
+            name: Alias(name, target=member, parent=self, inherited=False)
+            for name, member in final_target.members.items()
+        }
 
     @property
     def labels(self) -> set[str]:  # noqa: D102
@@ -982,7 +900,7 @@ class Alias(ObjectAliasMixin):
         return self.final_target.imports
 
     @property
-    def exports(self) -> set[str] | list[str | Name] | None:  # noqa: D102
+    def exports(self) -> set[str] | list[str | ExprName] | None:  # noqa: D102
         return self.final_target.exports
 
     @property
@@ -992,13 +910,13 @@ class Alias(ObjectAliasMixin):
     def member_is_exported(self, member: Object | Alias, *, explicitely: bool = True) -> bool:  # noqa: D102
         return self.final_target.member_is_exported(member, explicitely=explicitely)
 
-    @property
+    @cached_property
     def inherited_members(self) -> dict[str, Alias]:  # noqa: D102
-        return self.final_target.inherited_members
-
-    @property
-    def all_members(self) -> dict[str, Object | Alias]:  # noqa: D102
-        return self.final_target.all_members
+        final_target = self.final_target
+        return {
+            name: Alias(name, target=member, parent=self, inherited=True)
+            for name, member in final_target.inherited_members.items()
+        }
 
     def is_kind(self, kind: str | Kind | set[str | Kind]) -> bool:  # noqa: D102
         return self.final_target.is_kind(kind)
@@ -1025,22 +943,6 @@ class Alias(ObjectAliasMixin):
     def filter_members(self, *predicates: Callable[[Object | Alias], bool]) -> dict[str, Object | Alias]:  # noqa: D102
         return self.final_target.filter_members(*predicates)
 
-    @property
-    def modules(self) -> dict[str, Module]:  # noqa: D102
-        return self.final_target.modules
-
-    @property
-    def classes(self) -> dict[str, Class]:  # noqa: D102
-        return self.final_target.classes
-
-    @property
-    def functions(self) -> dict[str, Function]:  # noqa: D102
-        return self.final_target.functions
-
-    @property
-    def attributes(self) -> dict[str, Attribute]:  # noqa: D102
-        return self.final_target.attributes
-
     @property
     def module(self) -> Module:  # noqa: D102
         return self.final_target.module
@@ -1092,7 +994,7 @@ class Alias(ObjectAliasMixin):
         return cast(Module, self.target)._filepath
 
     @property
-    def bases(self) -> list[Name | Expression | str]:  # noqa: D102
+    def bases(self) -> list[Expr | str]:  # noqa: D102
         return cast(Class, self.target).bases
 
     @property
@@ -1112,11 +1014,11 @@ class Alias(ObjectAliasMixin):
         return cast(Function, self.target).parameters
 
     @property
-    def returns(self) -> str | Name | Expression | None:  # noqa: D102
+    def returns(self) -> str | Expr | None:  # noqa: D102
         return cast(Function, self.target).returns
 
     @returns.setter
-    def returns(self, returns: str | Name | Expression | None) -> None:
+    def returns(self, returns: str | Expr | None) -> None:
         cast(Function, self.target).returns = returns
 
     @property
@@ -1128,15 +1030,15 @@ class Alias(ObjectAliasMixin):
         return cast(Function, self.target).deleter
 
     @property
-    def value(self) -> str | Name | Expression | None:  # noqa: D102
+    def value(self) -> str | Expr | None:  # noqa: D102
         return cast(Attribute, self.target).value
 
     @property
-    def annotation(self) -> str | Name | Expression | None:  # noqa: D102
+    def annotation(self) -> str | Expr | None:  # noqa: D102
         return cast(Attribute, self.target).annotation
 
     @annotation.setter
-    def annotation(self, annotation: str | Name | Expression | None) -> None:
+    def annotation(self, annotation: str | Expr | None) -> None:
         cast(Attribute, self.target).annotation = annotation
 
     @property
@@ -1295,9 +1197,9 @@ class Module(Object):
 
     def __repr__(self) -> str:
         try:
-            return f"<Module({self.filepath!r})>"
+            return f"Module({self.filepath!r})"
         except BuiltinModuleError:
-            return f"<Module({self.name!r})>"
+            return f"Module({self.name!r})"
 
     @property
     def filepath(self) -> Path | list[Path]:
@@ -1410,7 +1312,7 @@ class Class(Object):
     def __init__(
         self,
         *args: Any,
-        bases: Sequence[Name | Expression | str] | None = None,
+        bases: Sequence[Expr | str] | None = None,
         decorators: list[Decorator] | None = None,
         **kwargs: Any,
     ) -> None:
@@ -1423,7 +1325,7 @@ class Class(Object):
             **kwargs: See [`griffe.dataclasses.Object`][].
         """
         super().__init__(*args, **kwargs)
-        self.bases: list[Name | Expression | str] = list(bases) if bases else []
+        self.bases: list[Expr | str] = list(bases) if bases else []
         self.decorators: list[Decorator] = decorators or []
         self.overloads: dict[str, list[Function]] = defaultdict(list)
 
@@ -1431,11 +1333,15 @@ class Class(Object):
     def parameters(self) -> Parameters:
         """Return the parameters of this class' `__init__` method, if any.
 
+        This property fetches inherited members,
+        and therefore is part of the consumer API:
+        do not use when producing Griffe trees!
+
         Returns:
-            The parameters containter.
+            The parameters container.
         """
         try:
-            return self.members["__init__"].parameters  # type: ignore[union-attr]
+            return self.all_members["__init__"].parameters  # type: ignore[union-attr]
         except KeyError:
             if "dataclass" in self.labels:
                 return Parameters(
@@ -1455,12 +1361,7 @@ class Class(Object):
         """
         resolved_bases = []
         for base in self.bases:
-            if isinstance(base, str):
-                base_path = base
-            elif isinstance(base, Name):
-                base_path = base.full
-            else:
-                base_path = base.without_subscript.full
+            base_path = base if isinstance(base, str) else base.canonical_path
             try:
                 resolved_base = self.modules_collection[base_path]
                 if resolved_base.is_alias:
@@ -1510,7 +1411,7 @@ class Function(Object):
         self,
         *args: Any,
         parameters: Parameters | None = None,
-        returns: str | Name | Expression | None = None,
+        returns: str | Expr | None = None,
         decorators: list[Decorator] | None = None,
         **kwargs: Any,
     ) -> None:
@@ -1525,14 +1426,14 @@ class Function(Object):
         """
         super().__init__(*args, **kwargs)
         self.parameters: Parameters = parameters or Parameters()
-        self.returns: str | Name | Expression | None = returns
+        self.returns: str | Expr | None = returns
         self.decorators: list[Decorator] = decorators or []
         self.setter: Function | None = None
         self.deleter: Function | None = None
         self.overloads: list[Function] | None = None
 
     @property
-    def annotation(self) -> str | Name | Expression | None:
+    def annotation(self) -> str | Expr | None:
         """Return the return annotation.
 
         Returns:
@@ -1564,8 +1465,8 @@ class Attribute(Object):
     def __init__(
         self,
         *args: Any,
-        value: str | Name | Expression | None = None,
-        annotation: str | Name | Expression | None = None,
+        value: str | Expr | None = None,
+        annotation: str | Expr | None = None,
         **kwargs: Any,
     ) -> None:
         """Initialize the function.
@@ -1577,8 +1478,8 @@ class Attribute(Object):
             **kwargs: See [`griffe.dataclasses.Object`][].
         """
         super().__init__(*args, **kwargs)
-        self.value: str | Name | Expression | None = value
-        self.annotation: str | Name | Expression | None = annotation
+        self.value: str | Expr | None = value
+        self.annotation: str | Expr | None = annotation
 
     def as_dict(self, **kwargs: Any) -> dict[str, Any]:
         """Return this function's data as a dictionary.
