@@ -3,13 +3,13 @@
 from __future__ import annotations
 
 import contextlib
-import enum
 from pathlib import Path
 from typing import Any, Iterable, Iterator
 
 from colorama import Fore, Style
 
 from griffe.dataclasses import Alias, Attribute, Class, Function, Object, ParameterKind
+from griffe.enumerations import BreakageKind, ExplanationStyle
 from griffe.exceptions import AliasResolutionError
 from griffe.git import WORKTREE_PREFIX
 from griffe.logger import get_logger
@@ -22,30 +22,6 @@ VARIADIC = frozenset((ParameterKind.var_positional, ParameterKind.var_keyword))
 logger = get_logger(__name__)
 
 
-class ExplanationStyle(enum.Enum):
-    """An enumeration of the possible styles for explanations."""
-
-    ONE_LINE: str = "oneline"
-    VERBOSE: str = "verbose"
-
-
-class BreakageKind(enum.Enum):
-    """An enumeration of the possible breakages."""
-
-    PARAMETER_MOVED: str = "Positional parameter was moved"
-    PARAMETER_REMOVED: str = "Parameter was removed"
-    PARAMETER_CHANGED_KIND: str = "Parameter kind was changed"
-    PARAMETER_CHANGED_DEFAULT: str = "Parameter default was changed"
-    PARAMETER_CHANGED_REQUIRED: str = "Parameter is now required"
-    PARAMETER_ADDED_REQUIRED: str = "Parameter was added as required"
-    RETURN_CHANGED_TYPE: str = "Return types are incompatible"
-    OBJECT_REMOVED: str = "Public object was removed"
-    OBJECT_CHANGED_KIND: str = "Public object points to a different kind of object"
-    ATTRIBUTE_CHANGED_TYPE: str = "Attribute types are incompatible"
-    ATTRIBUTE_CHANGED_VALUE: str = "Attribute value was changed"
-    CLASS_REMOVED_BASE: str = "Base class was removed"
-
-
 class Breakage:
     """Breakages can explain what broke from a version to another."""
 
@@ -66,10 +42,10 @@ class Breakage:
         self.details = details
 
     def __str__(self) -> str:
-        return f"{self.kind.value}"
+        return self.kind.value
 
     def __repr__(self) -> str:
-        return f"<{self.kind.name}>"
+        return self.kind.name
 
     def as_dict(self, *, full: bool = False, **kwargs: Any) -> dict[str, Any]:  # noqa: ARG002
         """Return this object's data as a dictionary.
@@ -336,10 +312,10 @@ class ClassRemovedBaseBreakage(Breakage):
     kind: BreakageKind = BreakageKind.CLASS_REMOVED_BASE
 
     def _format_old_value(self) -> str:
-        return "[" + ", ".join(base.full for base in self.old_value) + "]"
+        return "[" + ", ".join(base.canonical_path for base in self.old_value) + "]"
 
     def _format_new_value(self) -> str:
-        return "[" + ", ".join(base.full for base in self.new_value) + "]"
+        return "[" + ", ".join(base.canonical_path for base in self.new_value) + "]"
 
 
 # TODO: decorators!
@@ -470,14 +446,14 @@ def _member_incompatibilities(
     seen_paths: set[str] | None = None,
 ) -> Iterator[Breakage]:
     seen_paths = set() if seen_paths is None else seen_paths
-    for name, old_member in old_obj.members.items():
+    for name, old_member in old_obj.all_members.items():
         if ignore_private and name.startswith("_"):
             logger.debug(f"API check: {old_obj.path}.{name}: skip private object")
             continue
 
         logger.debug(f"API check: {old_obj.path}.{name}")
         try:
-            new_member = new_obj.members[name]
+            new_member = new_obj.all_members[name]
         except KeyError:
             is_module = not old_member.is_alias and old_member.is_module
             if is_module or old_member.is_exported(explicitely=False):
