@@ -8,6 +8,9 @@ from typing import TYPE_CHECKING, List, Tuple
 
 from griffe.docstrings.dataclasses import (
     DocstringAttribute,
+    DocstringClass,
+    DocstringFunction,
+    DocstringModule,
     DocstringParameter,
     DocstringRaise,
     DocstringReceive,
@@ -15,9 +18,12 @@ from griffe.docstrings.dataclasses import (
     DocstringSection,
     DocstringSectionAdmonition,
     DocstringSectionAttributes,
+    DocstringSectionClasses,
     DocstringSectionDeprecated,
     DocstringSectionExamples,
+    DocstringSectionFunctions,
     DocstringSectionKind,
+    DocstringSectionModules,
     DocstringSectionOtherParameters,
     DocstringSectionParameters,
     DocstringSectionRaises,
@@ -30,12 +36,14 @@ from griffe.docstrings.dataclasses import (
     DocstringYield,
 )
 from griffe.docstrings.utils import parse_annotation, warning
-from griffe.expressions import Expression, Name
+from griffe.expressions import ExprName
+from griffe.logger import LogLevel
 
 if TYPE_CHECKING:
     from typing import Any, Literal, Pattern
 
     from griffe.dataclasses import Docstring
+    from griffe.expressions import Expr
 
 _warn = warning(__name__)
 
@@ -57,6 +65,10 @@ _section_kind = {
     "receives": DocstringSectionKind.receives,
     "examples": DocstringSectionKind.examples,
     "attributes": DocstringSectionKind.attributes,
+    "functions": DocstringSectionKind.functions,
+    "methods": DocstringSectionKind.functions,
+    "classes": DocstringSectionKind.classes,
+    "modules": DocstringSectionKind.modules,
     "warns": DocstringSectionKind.warns,
     "warnings": DocstringSectionKind.warns,
 }
@@ -71,7 +83,7 @@ _RE_DOCTEST_BLANKLINE: Pattern = re.compile(r"^\s*<BLANKLINE>\s*$")
 _RE_DOCTEST_FLAGS: Pattern = re.compile(r"(\s*#\s*doctest:.+)$")
 
 
-def _read_block_items(docstring: Docstring, *, offset: int) -> ItemsBlock:
+def _read_block_items(docstring: Docstring, *, offset: int, **options: Any) -> ItemsBlock:  # noqa: ARG001
     lines = docstring.lines
     if offset >= len(lines):
         return [], offset
@@ -134,7 +146,7 @@ def _read_block_items(docstring: Docstring, *, offset: int) -> ItemsBlock:
     return items, new_offset - 1
 
 
-def _read_block(docstring: Docstring, *, offset: int) -> tuple[str, int]:
+def _read_block(docstring: Docstring, *, offset: int, **options: Any) -> tuple[str, int]:  # noqa: ARG001
     lines = docstring.lines
     if offset >= len(lines):
         return "", offset - 1
@@ -170,11 +182,12 @@ def _read_parameters(
     *,
     offset: int,
     warn_unknown_params: bool = True,
+    **options: Any,
 ) -> tuple[list[DocstringParameter], int]:
     parameters = []
-    annotation: str | Name | Expression | None
+    annotation: str | Expr | None
 
-    block, new_offset = _read_block_items(docstring, offset=offset)
+    block, new_offset = _read_block_items(docstring, offset=offset, **options)
 
     for line_number, param_lines in block:
         # check the presence of a name and description, separated by a colon
@@ -230,42 +243,33 @@ def _read_parameters_section(
     docstring: Docstring,
     *,
     offset: int,
-    **options: Any,  # noqa: ARG001
+    **options: Any,
 ) -> tuple[DocstringSectionParameters | None, int]:
-    parameters, new_offset = _read_parameters(docstring, offset=offset)
-
-    if parameters:
-        return DocstringSectionParameters(parameters), new_offset
-
-    _warn(docstring, new_offset, f"Empty parameters section at line {offset}")
-    return None, new_offset
+    parameters, new_offset = _read_parameters(docstring, offset=offset, **options)
+    return DocstringSectionParameters(parameters), new_offset
 
 
 def _read_other_parameters_section(
     docstring: Docstring,
     *,
     offset: int,
-    **options: Any,  # noqa: ARG001
+    warn_unknown_params: bool = True,  # noqa: ARG001
+    **options: Any,
 ) -> tuple[DocstringSectionOtherParameters | None, int]:
-    parameters, new_offset = _read_parameters(docstring, offset=offset, warn_unknown_params=False)
-
-    if parameters:
-        return DocstringSectionOtherParameters(parameters), new_offset
-
-    _warn(docstring, new_offset, f"Empty other parameters section at line {offset}")
-    return None, new_offset
+    parameters, new_offset = _read_parameters(docstring, offset=offset, warn_unknown_params=False, **options)
+    return DocstringSectionOtherParameters(parameters), new_offset
 
 
 def _read_attributes_section(
     docstring: Docstring,
     *,
     offset: int,
-    **options: Any,  # noqa: ARG001
+    **options: Any,
 ) -> tuple[DocstringSectionAttributes | None, int]:
     attributes = []
-    block, new_offset = _read_block_items(docstring, offset=offset)
+    block, new_offset = _read_block_items(docstring, offset=offset, **options)
 
-    annotation: str | Name | Expression | None = None
+    annotation: str | Expr | None = None
     for line_number, attr_lines in block:
         try:
             name_with_type, description = attr_lines[0].split(":", 1)
@@ -289,23 +293,102 @@ def _read_attributes_section(
 
         attributes.append(DocstringAttribute(name=name, annotation=annotation, description=description))
 
-    if attributes:
-        return DocstringSectionAttributes(attributes), new_offset
+    return DocstringSectionAttributes(attributes), new_offset
 
-    _warn(docstring, new_offset, f"Empty attributes section at line {offset}")
-    return None, new_offset
+
+def _read_functions_section(
+    docstring: Docstring,
+    *,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionFunctions | None, int]:
+    functions = []
+    block, new_offset = _read_block_items(docstring, offset=offset, **options)
+
+    signature: str | Expr | None = None
+    for line_number, func_lines in block:
+        try:
+            name_with_signature, description = func_lines[0].split(":", 1)
+        except ValueError:
+            _warn(docstring, line_number, f"Failed to get 'signature: description' pair from '{func_lines[0]}'")
+            continue
+
+        description = "\n".join([description.lstrip(), *func_lines[1:]]).rstrip("\n")
+
+        if "(" in name_with_signature:
+            name = name_with_signature.split("(", 1)[0]
+            signature = name_with_signature
+        else:
+            name = name_with_signature
+            signature = None
+
+        functions.append(DocstringFunction(name=name, annotation=signature, description=description))
+
+    return DocstringSectionFunctions(functions), new_offset
+
+
+def _read_classes_section(
+    docstring: Docstring,
+    *,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionClasses | None, int]:
+    classes = []
+    block, new_offset = _read_block_items(docstring, offset=offset, **options)
+
+    signature: str | Expr | None = None
+    for line_number, class_lines in block:
+        try:
+            name_with_signature, description = class_lines[0].split(":", 1)
+        except ValueError:
+            _warn(docstring, line_number, f"Failed to get 'signature: description' pair from '{class_lines[0]}'")
+            continue
+
+        description = "\n".join([description.lstrip(), *class_lines[1:]]).rstrip("\n")
+
+        if "(" in name_with_signature:
+            name = name_with_signature.split("(", 1)[0]
+            signature = name_with_signature
+        else:
+            name = name_with_signature
+            signature = None
+
+        classes.append(DocstringClass(name=name, annotation=signature, description=description))
+
+    return DocstringSectionClasses(classes), new_offset
+
+
+def _read_modules_section(
+    docstring: Docstring,
+    *,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionModules | None, int]:
+    modules = []
+    block, new_offset = _read_block_items(docstring, offset=offset, **options)
+
+    for line_number, module_lines in block:
+        try:
+            name, description = module_lines[0].split(":", 1)
+        except ValueError:
+            _warn(docstring, line_number, f"Failed to get 'name: description' pair from '{module_lines[0]}'")
+            continue
+        description = "\n".join([description.lstrip(), *module_lines[1:]]).rstrip("\n")
+        modules.append(DocstringModule(name=name, description=description))
+
+    return DocstringSectionModules(modules), new_offset
 
 
 def _read_raises_section(
     docstring: Docstring,
     *,
     offset: int,
-    **options: Any,  # noqa: ARG001
+    **options: Any,
 ) -> tuple[DocstringSectionRaises | None, int]:
     exceptions = []
-    block, new_offset = _read_block_items(docstring, offset=offset)
+    block, new_offset = _read_block_items(docstring, offset=offset, **options)
 
-    annotation: str | Name | Expression
+    annotation: str | Expr
     for line_number, exception_lines in block:
         try:
             annotation, description = exception_lines[0].split(":", 1)
@@ -317,21 +400,17 @@ def _read_raises_section(
             annotation = parse_annotation(annotation, docstring)
             exceptions.append(DocstringRaise(annotation=annotation, description=description))
 
-    if exceptions:
-        return DocstringSectionRaises(exceptions), new_offset
-
-    _warn(docstring, new_offset, f"Empty exceptions section at line {offset}")
-    return None, new_offset
+    return DocstringSectionRaises(exceptions), new_offset
 
 
 def _read_warns_section(
     docstring: Docstring,
     *,
     offset: int,
-    **options: Any,  # noqa: ARG001
+    **options: Any,
 ) -> tuple[DocstringSectionWarns | None, int]:
     warns = []
-    block, new_offset = _read_block_items(docstring, offset=offset)
+    block, new_offset = _read_block_items(docstring, offset=offset, **options)
 
     for line_number, warning_lines in block:
         try:
@@ -342,29 +421,40 @@ def _read_warns_section(
             description = "\n".join([description.lstrip(), *warning_lines[1:]]).rstrip("\n")
             warns.append(DocstringWarn(annotation=annotation, description=description))
 
-    if warns:
-        return DocstringSectionWarns(warns), new_offset
-
-    _warn(docstring, new_offset, f"Empty warns section at line {offset}")
-    return None, new_offset
+    return DocstringSectionWarns(warns), new_offset
 
 
 def _read_returns_section(
     docstring: Docstring,
     *,
     offset: int,
-    **options: Any,  # noqa: ARG001
+    returns_multiple_items: bool = True,
+    returns_named_value: bool = True,
+    **options: Any,
 ) -> tuple[DocstringSectionReturns | None, int]:
     returns = []
-    block, new_offset = _read_block_items(docstring, offset=offset)
+
+    if returns_multiple_items:
+        block, new_offset = _read_block_items(docstring, offset=offset, **options)
+    else:
+        one_block, new_offset = _read_block(docstring, offset=offset, **options)
+        block = [(new_offset, one_block.splitlines())]
 
     for index, (line_number, return_lines) in enumerate(block):
-        match = _RE_NAME_ANNOTATION_DESCRIPTION.match(return_lines[0])
-        if not match:
-            _warn(docstring, line_number, f"Failed to get name, annotation or description from '{return_lines[0]}'")
-            continue
-
-        name, annotation, description = match.groups()
+        if returns_named_value:
+            match = _RE_NAME_ANNOTATION_DESCRIPTION.match(return_lines[0])
+            if not match:
+                _warn(docstring, line_number, f"Failed to get name, annotation or description from '{return_lines[0]}'")
+                continue
+            name, annotation, description = match.groups()
+        else:
+            name = None
+            if ":" in return_lines[0]:
+                annotation, description = return_lines[0].split(":", 1)
+                annotation = annotation.lstrip("(").rstrip(")")
+            else:
+                annotation = None
+                description = return_lines[0]
         description = "\n".join([description.lstrip(), *return_lines[1:]]).rstrip("\n")
 
         if annotation:
@@ -381,18 +471,18 @@ def _read_returns_section(
                     raise ValueError
                 if len(block) > 1:
                     if annotation.is_tuple:
-                        annotation = annotation.tuple_item(index)
+                        annotation = annotation.slice.elements[index]
                     else:
                         if annotation.is_iterator:
-                            return_item = annotation.iterator_item()
+                            return_item = annotation.slice
                         elif annotation.is_generator:
-                            _, _, return_item = annotation.generator_items()
+                            return_item = annotation.slice.elements[2]
                         else:
                             raise ValueError
-                        if isinstance(return_item, Name):
+                        if isinstance(return_item, ExprName):
                             annotation = return_item
                         elif return_item.is_tuple:
-                            annotation = return_item.tuple_item(index)
+                            annotation = return_item.slice.elements[index]
                         else:
                             annotation = return_item
 
@@ -402,21 +492,17 @@ def _read_returns_section(
 
         returns.append(DocstringReturn(name=name or "", annotation=annotation, description=description))
 
-    if returns:
-        return DocstringSectionReturns(returns), new_offset
-
-    _warn(docstring, new_offset, f"Empty returns section at line {offset}")
-    return None, new_offset
+    return DocstringSectionReturns(returns), new_offset
 
 
 def _read_yields_section(
     docstring: Docstring,
     *,
     offset: int,
-    **options: Any,  # noqa: ARG001
+    **options: Any,
 ) -> tuple[DocstringSectionYields | None, int]:
     yields = []
-    block, new_offset = _read_block_items(docstring, offset=offset)
+    block, new_offset = _read_block_items(docstring, offset=offset, **options)
 
     for index, (line_number, yield_lines) in enumerate(block):
         match = _RE_NAME_ANNOTATION_DESCRIPTION.match(yield_lines[0])
@@ -435,15 +521,15 @@ def _read_yields_section(
             with suppress(AttributeError, KeyError, ValueError):
                 annotation = docstring.parent.returns  # type: ignore[union-attr]
                 if annotation.is_iterator:
-                    yield_item = annotation.iterator_item()
+                    yield_item = annotation.slice
                 elif annotation.is_generator:
-                    yield_item, _, _ = annotation.generator_items()
+                    yield_item = annotation.slice.elements[0]
                 else:
                     raise ValueError
-                if isinstance(yield_item, Name):
+                if isinstance(yield_item, ExprName):
                     annotation = yield_item
                 elif yield_item.is_tuple:
-                    annotation = yield_item.tuple_item(index)
+                    annotation = yield_item.slice.elements[index]
                 else:
                     annotation = yield_item
 
@@ -453,21 +539,17 @@ def _read_yields_section(
 
         yields.append(DocstringYield(name=name or "", annotation=annotation, description=description))
 
-    if yields:
-        return DocstringSectionYields(yields), new_offset
-
-    _warn(docstring, new_offset, f"Empty yields section at line {offset}")
-    return None, new_offset
+    return DocstringSectionYields(yields), new_offset
 
 
 def _read_receives_section(
     docstring: Docstring,
     *,
     offset: int,
-    **options: Any,  # noqa: ARG001
+    **options: Any,
 ) -> tuple[DocstringSectionReceives | None, int]:
     receives = []
-    block, new_offset = _read_block_items(docstring, offset=offset)
+    block, new_offset = _read_block_items(docstring, offset=offset, **options)
 
     for index, (line_number, receive_lines) in enumerate(block):
         match = _RE_NAME_ANNOTATION_DESCRIPTION.match(receive_lines[0])
@@ -486,11 +568,11 @@ def _read_receives_section(
             with suppress(AttributeError, KeyError):
                 annotation = docstring.parent.returns  # type: ignore[union-attr]
                 if annotation.is_generator:
-                    _, receives_item, _ = annotation.generator_items()
-                    if isinstance(receives_item, Name):
+                    receives_item = annotation.slice.elements[1]
+                    if isinstance(receives_item, ExprName):
                         annotation = receives_item
                     elif receives_item.is_tuple:
-                        annotation = receives_item.tuple_item(index)
+                        annotation = receives_item.slice.elements[index]
                     else:
                         annotation = receives_item
 
@@ -500,11 +582,7 @@ def _read_receives_section(
 
         receives.append(DocstringReceive(name=name or "", annotation=annotation, description=description))
 
-    if receives:
-        return DocstringSectionReceives(receives), new_offset
-
-    _warn(docstring, new_offset, f"Empty receives section at line {offset}")
-    return None, new_offset
+    return DocstringSectionReceives(receives), new_offset
 
 
 def _read_examples_section(
@@ -512,11 +590,11 @@ def _read_examples_section(
     *,
     offset: int,
     trim_doctest_flags: bool = True,
-    **options: Any,  # noqa: ARG001
+    **options: Any,
 ) -> tuple[DocstringSectionExamples | None, int]:
-    text, new_offset = _read_block(docstring, offset=offset)
+    text, new_offset = _read_block(docstring, offset=offset, **options)
 
-    sub_sections: list[tuple[Literal[DocstringSectionKind.text] | Literal[DocstringSectionKind.examples], str]] = []
+    sub_sections: list[tuple[Literal[DocstringSectionKind.text, DocstringSectionKind.examples], str]] = []
     in_code_example = False
     in_code_block = False
     current_text: list[str] = []
@@ -563,25 +641,16 @@ def _read_examples_section(
     elif current_example:
         sub_sections.append((DocstringSectionKind.examples, "\n".join(current_example)))
 
-    if sub_sections:
-        return DocstringSectionExamples(sub_sections), new_offset
-
-    _warn(docstring, new_offset, f"Empty examples section at line {offset}")
-    return None, new_offset
+    return DocstringSectionExamples(sub_sections), new_offset
 
 
 def _read_deprecated_section(
     docstring: Docstring,
     *,
     offset: int,
-    **options: Any,  # noqa: ARG001
+    **options: Any,
 ) -> tuple[DocstringSectionDeprecated | None, int]:
-    text, new_offset = _read_block(docstring, offset=offset)
-
-    # early exit if there is no text in the yield section
-    if not text:
-        _warn(docstring, new_offset, f"Empty deprecated section at line {offset}")
-        return None, new_offset
+    text, new_offset = _read_block(docstring, offset=offset, **options)
 
     # check the presence of a name and description, separated by a semi-colon
     try:
@@ -610,18 +679,27 @@ _section_reader = {
     DocstringSectionKind.warns: _read_warns_section,
     DocstringSectionKind.examples: _read_examples_section,
     DocstringSectionKind.attributes: _read_attributes_section,
+    DocstringSectionKind.functions: _read_functions_section,
+    DocstringSectionKind.classes: _read_classes_section,
+    DocstringSectionKind.modules: _read_modules_section,
     DocstringSectionKind.returns: _read_returns_section,
     DocstringSectionKind.yields: _read_yields_section,
     DocstringSectionKind.receives: _read_receives_section,
     DocstringSectionKind.deprecated: _read_deprecated_section,
 }
 
+_sentinel = object()
+
 
 def parse(
     docstring: Docstring,
     *,
     ignore_init_summary: bool = False,
     trim_doctest_flags: bool = True,
+    returns_multiple_items: bool = True,
+    warn_unknown_params: bool = True,
+    returns_named_value: bool = True,
+    returns_type_in_property_summary: bool = False,
     **options: Any,
 ) -> list[DocstringSection]:
     """Parse a docstring.
@@ -633,6 +711,13 @@ def parse(
         docstring: The docstring to parse.
         ignore_init_summary: Whether to ignore the summary in `__init__` methods' docstrings.
         trim_doctest_flags: Whether to remove doctest flags from Python example blocks.
+        returns_multiple_items: Whether the `Returns` section has multiple items.
+        warn_unknown_params: Warn about documented parameters not appearing in the signature.
+        returns_named_value: Whether to parse `thing: Description` in returns sections as a name and description,
+            rather than a type and description. When true, type must be wrapped in parentheses: `(int): Description.`.
+            When false, parentheses are optional but the items cannot be named: `int: Description`.
+        returns_type_in_property_summary: Whether to parse the return type of properties
+            at the beginning of their summary: `str: Summary of the property`.
         **options: Additional parsing options.
 
     Returns:
@@ -647,6 +732,10 @@ def parse(
     options = {
         "ignore_init_summary": ignore_init_summary,
         "trim_doctest_flags": trim_doctest_flags,
+        "returns_multiple_items": returns_multiple_items,
+        "warn_unknown_params": warn_unknown_params,
+        "returns_named_value": returns_named_value,
+        "returns_type_in_property_summary": returns_type_in_property_summary,
         **options,
     }
 
@@ -677,7 +766,41 @@ def parse(
             groups = match.groupdict()
             title = groups["title"]
             admonition_type = groups["type"]
-            if admonition_type.lower() in _section_kind:
+            is_section = admonition_type.lower() in _section_kind
+
+            has_previous_line = offset > 0
+            blank_line_above = not has_previous_line or _is_empty_line(lines[offset - 1])
+            has_next_line = offset < len(lines) - 1
+            has_next_lines = offset < len(lines) - 2
+            blank_line_below = has_next_line and _is_empty_line(lines[offset + 1])
+            blank_lines_below = has_next_lines and _is_empty_line(lines[offset + 2])
+            indented_line_below = has_next_line and not blank_line_below and lines[offset + 1].startswith(" ")
+            indented_lines_below = has_next_lines and not blank_lines_below and lines[offset + 2].startswith(" ")
+            if not (indented_line_below or indented_lines_below):
+                # Do not warn when there are no contents,
+                # this is most probably not a section or admonition.
+                current_section.append(lines[offset])
+                offset += 1
+                continue
+            reasons = []
+            kind = "section" if is_section else "admonition"
+            if (indented_line_below or indented_lines_below) and not blank_line_above:
+                reasons.append(f"Missing blank line above {kind}")
+            if indented_lines_below and blank_line_below:
+                reasons.append(f"Extraneous blank line below {kind} title")
+            if reasons:
+                reasons_string = "; ".join(reasons)
+                _warn(
+                    docstring,
+                    offset,
+                    f"Possible {kind} skipped, reasons: {reasons_string}",
+                    LogLevel.debug,
+                )
+                current_section.append(lines[offset])
+                offset += 1
+                continue
+
+            if is_section:
                 if current_section:
                     if any(current_section):
                         sections.append(DocstringSectionText("\n".join(current_section).rstrip("\n")))
@@ -710,6 +833,24 @@ def parse(
     if current_section:
         sections.append(DocstringSectionText("\n".join(current_section).rstrip("\n")))
 
+    if (
+        returns_type_in_property_summary
+        and sections
+        and docstring.parent
+        and docstring.parent.is_attribute
+        and "property" in docstring.parent.labels
+    ):
+        lines = sections[0].value.lstrip().split("\n")
+        if ":" in lines[0]:
+            annotation, line = lines[0].split(":", 1)
+            lines = [line, *lines[1:]]
+            sections[0].value = "\n".join(lines)
+            sections.append(
+                DocstringSectionReturns(
+                    [DocstringReturn("", description="", annotation=parse_annotation(annotation, docstring))],
+                ),
+            )
+
     return sections
 
 
