@@ -45,15 +45,21 @@ from typing import TYPE_CHECKING
 
 from griffe.docstrings.dataclasses import (
     DocstringAttribute,
+    DocstringClass,
+    DocstringFunction,
+    DocstringModule,
     DocstringParameter,
     DocstringRaise,
     DocstringReceive,
     DocstringReturn,
     DocstringSection,
     DocstringSectionAttributes,
+    DocstringSectionClasses,
     DocstringSectionDeprecated,
     DocstringSectionExamples,
+    DocstringSectionFunctions,
     DocstringSectionKind,
+    DocstringSectionModules,
     DocstringSectionOtherParameters,
     DocstringSectionParameters,
     DocstringSectionRaises,
@@ -66,13 +72,14 @@ from griffe.docstrings.dataclasses import (
     DocstringYield,
 )
 from griffe.docstrings.utils import parse_annotation, warning
-from griffe.expressions import Expression, Name
+from griffe.expressions import ExprName
 from griffe.logger import LogLevel
 
 if TYPE_CHECKING:
     from typing import Any, Literal, Pattern
 
     from griffe.dataclasses import Docstring
+    from griffe.expressions import Expr
 
 
 _warn = warning(__name__)
@@ -88,6 +95,10 @@ _section_kind = {
     "warns": DocstringSectionKind.warns,
     "examples": DocstringSectionKind.examples,
     "attributes": DocstringSectionKind.attributes,
+    "functions": DocstringSectionKind.functions,
+    "methods": DocstringSectionKind.functions,
+    "classes": DocstringSectionKind.classes,
+    "modules": DocstringSectionKind.modules,
 }
 
 
@@ -175,7 +186,7 @@ def _read_block_items(
     return items, new_offset - 1
 
 
-def _read_block(docstring: Docstring, *, offset: int) -> tuple[str, int]:
+def _read_block(docstring: Docstring, *, offset: int, **options: Any) -> tuple[str, int]:  # noqa: ARG001
     lines = docstring.lines
     if offset >= len(lines):
         return "", offset
@@ -245,7 +256,7 @@ def _read_parameters(
     **options: Any,
 ) -> tuple[list[DocstringParameter], int]:
     parameters = []
-    annotation: str | Name | Expression | None
+    annotation: str | Expr | None
 
     items, new_offset = _read_block_items(docstring, offset=offset, **options)
 
@@ -325,6 +336,7 @@ def _read_other_parameters_section(
     docstring: Docstring,
     *,
     offset: int,
+    warn_unknown_params: bool = True,  # noqa: ARG001
     **options: Any,
 ) -> tuple[DocstringSectionOtherParameters | None, int]:
     parameters, new_offset = _read_parameters(docstring, offset=offset, warn_unknown_params=False, **options)
@@ -396,18 +408,18 @@ def _read_returns_section(
                     raise ValueError
                 if len(items) > 1:
                     if annotation.is_tuple:
-                        annotation = annotation.tuple_item(index)
+                        annotation = annotation.slice.elements[index]
                     else:
                         if annotation.is_iterator:
-                            return_item = annotation.iterator_item()
+                            return_item = annotation.slice
                         elif annotation.is_generator:
-                            _, _, return_item = annotation.generator_items()
+                            return_item = annotation.slice.elements[2]
                         else:
                             raise ValueError
-                        if isinstance(return_item, Name):
+                        if isinstance(return_item, ExprName):
                             annotation = return_item
                         elif return_item.is_tuple:
-                            annotation = return_item.tuple_item(index)
+                            annotation = return_item.slice.elements[index]
                         else:
                             annotation = return_item
         else:
@@ -447,15 +459,15 @@ def _read_yields_section(
             with suppress(AttributeError, KeyError, ValueError):
                 annotation = docstring.parent.returns  # type: ignore[union-attr]
                 if annotation.is_iterator:
-                    yield_item = annotation.iterator_item()
+                    yield_item = annotation.slice
                 elif annotation.is_generator:
-                    yield_item, _, _ = annotation.generator_items()
+                    yield_item = annotation.slice.elements[0]
                 else:
                     raise ValueError
-                if isinstance(yield_item, Name):
+                if isinstance(yield_item, ExprName):
                     annotation = yield_item
                 elif yield_item.is_tuple:
-                    annotation = yield_item.tuple_item(index)
+                    annotation = yield_item.slice.elements[index]
                 else:
                     annotation = yield_item
         else:
@@ -495,11 +507,11 @@ def _read_receives_section(
             with suppress(AttributeError, KeyError):
                 annotation = docstring.parent.returns  # type: ignore[union-attr]
                 if annotation.is_generator:
-                    _, receives_item, _ = annotation.generator_items()
-                    if isinstance(receives_item, Name):
+                    receives_item = annotation.slice.elements[1]
+                    if isinstance(receives_item, ExprName):
                         annotation = receives_item
                     elif receives_item.is_tuple:
-                        annotation = receives_item.tuple_item(index)
+                        annotation = receives_item.slice.elements[index]
                     else:
                         annotation = receives_item
         else:
@@ -569,7 +581,7 @@ def _read_attributes_section(
         _warn(docstring, new_offset, f"Empty attributes section at line {offset}")
         return None, new_offset
 
-    annotation: str | Name | Expression | None
+    annotation: str | Expr | None
     attributes = []
     for item in items:
         name_type = item[0]
@@ -590,16 +602,106 @@ def _read_attributes_section(
     return DocstringSectionAttributes(attributes), new_offset
 
 
+def _read_functions_section(
+    docstring: Docstring,
+    *,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionFunctions | None, int]:
+    # SIGNATURE
+    #    TEXT?
+    items, new_offset = _read_block_items(docstring, offset=offset, **options)
+
+    if not items:
+        _warn(docstring, new_offset, f"Empty functions/methods section at line {offset}")
+        return None, new_offset
+
+    functions = []
+    signature: str | Expr | None
+    for item in items:
+        name_signature = item[0]
+        if "(" in name_signature:
+            name = name_signature.split("(", 1)[0]
+            name = name.strip()
+            signature = name_signature.strip()
+        else:
+            name = name_signature
+            signature = None
+        text = dedent("\n".join(item[1:])).strip()
+        functions.append(DocstringFunction(name=name, annotation=signature, description=text))
+    return DocstringSectionFunctions(functions), new_offset
+
+
+def _read_classes_section(
+    docstring: Docstring,
+    *,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionClasses | None, int]:
+    # SIGNATURE
+    #    TEXT?
+    items, new_offset = _read_block_items(docstring, offset=offset, **options)
+
+    if not items:
+        _warn(docstring, new_offset, f"Empty classes section at line {offset}")
+        return None, new_offset
+
+    classes = []
+    signature: str | Expr | None
+    for item in items:
+        name_signature = item[0]
+        if "(" in name_signature:
+            name = name_signature.split("(", 1)[0]
+            name = name.strip()
+            signature = name_signature.strip()
+        else:
+            name = name_signature
+            signature = None
+        text = dedent("\n".join(item[1:])).strip()
+        classes.append(DocstringClass(name=name, annotation=signature, description=text))
+    return DocstringSectionClasses(classes), new_offset
+
+
+def _read_modules_section(
+    docstring: Docstring,
+    *,
+    offset: int,
+    **options: Any,
+) -> tuple[DocstringSectionModules | None, int]:
+    # NAME
+    #    TEXT?
+    items, new_offset = _read_block_items(docstring, offset=offset, **options)
+
+    if not items:
+        _warn(docstring, new_offset, f"Empty modules section at line {offset}")
+        return None, new_offset
+
+    modules = []
+    signature: str | Expr | None
+    for item in items:
+        name_signature = item[0]
+        if "(" in name_signature:
+            name = name_signature.split("(", 1)[0]
+            name = name.strip()
+            signature = name_signature.strip()
+        else:
+            name = name_signature
+            signature = None
+        text = dedent("\n".join(item[1:])).strip()
+        modules.append(DocstringModule(name=name, annotation=signature, description=text))
+    return DocstringSectionModules(modules), new_offset
+
+
 def _read_examples_section(
     docstring: Docstring,
     *,
     offset: int,
     trim_doctest_flags: bool = True,
-    **options: Any,  # noqa: ARG001
+    **options: Any,
 ) -> tuple[DocstringSectionExamples | None, int]:
-    text, new_offset = _read_block(docstring, offset=offset)
+    text, new_offset = _read_block(docstring, offset=offset, **options)
 
-    sub_sections: list[tuple[Literal[DocstringSectionKind.text] | Literal[DocstringSectionKind.examples], str]] = []
+    sub_sections: list[tuple[Literal[DocstringSectionKind.text, DocstringSectionKind.examples], str]] = []
     in_code_example = False
     in_code_block = False
     current_text: list[str] = []
@@ -661,6 +763,9 @@ _section_reader = {
     DocstringSectionKind.warns: _read_warns_section,
     DocstringSectionKind.examples: _read_examples_section,
     DocstringSectionKind.attributes: _read_attributes_section,
+    DocstringSectionKind.functions: _read_functions_section,
+    DocstringSectionKind.classes: _read_classes_section,
+    DocstringSectionKind.modules: _read_modules_section,
     DocstringSectionKind.returns: _read_returns_section,
     DocstringSectionKind.yields: _read_yields_section,
     DocstringSectionKind.receives: _read_receives_section,
@@ -673,6 +778,7 @@ def parse(
     ignore_init_summary: bool = False,
     trim_doctest_flags: bool = True,
     allow_section_blank_line: bool = False,
+    warn_unknown_params: bool = True,
     **options: Any,
 ) -> list[DocstringSection]:
     """Parse a docstring.
@@ -687,6 +793,7 @@ def parse(
         allow_section_blank_line: Whether to continue a section if there's an empty line
             between items in a formatted block, like Parameters or Returns.
             If True, you can still create a new section using two empty lines.
+        warn_unknown_params: Warn about documented parameters not appearing in the signature.
         **options: Additional parsing options.
 
     Returns:
@@ -702,6 +809,7 @@ def parse(
         "trim_doctest_flags": trim_doctest_flags,
         "ignore_init_summary": ignore_init_summary,
         "allow_section_blank_line": allow_section_blank_line,
+        "warn_unknown_params": warn_unknown_params,
         **options,
     }
 
